@@ -94,7 +94,7 @@ CHECK_WARNINGS() {
 # print warnings found in the compile-stage output
 # $1 = file with the compile-stage output
 COMPILE_WARNINGS() {
-  whitelist='\(no[[:space:]]link[[:space:]]for:\|Value[[:space:]]descriptions\|unused[[:space:]]declarations\|g_type_class_add_private.*is[[:space:]]deprecated\|g-ir-scanner:\|clang.*argument[[:space:]]unused[[:space:]]during[[:space:]]compilation\|U_PLATFORM_HAS_WINUWP_API\|DB_DBM_HSEARCH\|const[[:space:]]DBT\|db\.h\)'
+  whitelist='\(no[[:space:]]link[[:space:]]for:\|Value[[:space:]]descriptions\|unused[[:space:]]declarations\|G_ADD_PRIVATE\|g_type_class_add_private.*is[[:space:]]deprecated\|g-ir-scanner:\|clang.*argument[[:space:]]unused[[:space:]]during[[:space:]]compilation\|U_PLATFORM_HAS_WINUWP_API\|const[[:space:]]DBT\)'
   CHECK_WARNINGS $1 "warning:" "$whitelist"
 }
 
@@ -109,7 +109,7 @@ CPPCHECK_WARNINGS() {
 # print warnings find in the clang-tidy output
 # $1 = file with the clang-tidy output
 TIDY_WARNINGS() {
-  whitelist='\(Value[[:space:]]descriptions\|unused[[:space:]]declarations\|g-ir-scanner:\|clang.*argument[[:space:]]unused[[:space:]]during[[:space:]]compilation\|modernize-\|cppcoreguidelines-pro-type-const-cast\|cppcoreguidelines-pro-type-reinterpret-cast\|cppcoreguidelines-owning-memory\|fuchsia.*\|hicpp-use-auto\|hicpp-no-malloc\|hicpp-use-nullptr\|hicpp-exception-baseclass\|cppcoreguidelines-pro-type-vararg\|cppcoreguidelines-pro-bounds-pointer-arithmetic\|google-build-using-namespace\|llvm-include-order\|hicpp-use-equals-default\|cppcoreguidelines-no-malloc\|g_type_class_add_private.*is[[:space:]]deprecated\)'
+  whitelist='\(Value[[:space:]]descriptions\|unused[[:space:]]declarations\|g-ir-scanner:\|clang.*argument[[:space:]]unused[[:space:]]during[[:space:]]compilation\|modernize-\|cppcoreguidelines-pro-type-const-cast\|cppcoreguidelines-pro-type-reinterpret-cast\|cppcoreguidelines-owning-memory\|fuchsia.*\|hicpp-use-auto\|hicpp-no-malloc\|hicpp-use-nullptr\|hicpp-exception-baseclass\|hicpp-vararg\|cppcoreguidelines-pro-type-vararg\|cppcoreguidelines-pro-bounds-pointer-arithmetic\|google-build-using-namespace\|llvm-include-order\|hicpp-use-equals-default\|cppcoreguidelines-no-malloc\|g_type_class_add_private.*is[[:space:]]deprecated\)'
   CHECK_WARNINGS $1 "warning:" "$whitelist"
 }
 
@@ -245,9 +245,10 @@ CPPCHECK() {
 
   echo "===== START CPPCHECK: $1 ======"
   cd $TOP
-  cppcheck --quiet --std=posix --language=c \
+  cppcheck --quiet --language=c \
            --force --error-exitcode=1 --inline-suppr \
            --enable=warning,performance,portability,information \
+           --template='{file}:{line},{severity},{id},{message}' \
            -D sleep="" \
            -D localtime_r="" \
            -D gmtime_r="" \
@@ -491,29 +492,29 @@ CLANGTIDY test2 "$CMAKEOPTS"
 CLANGTIDY test2builtin "$TZCMAKEOPTS"
 
 #GCC based build tests
-GCC_BUILD test1 ""
-GCC_BUILD test2 "$CMAKEOPTS"
-GCC_BUILD test3 "$UUCCMAKEOPTS"
-GCC_BUILD test4 "$GLIBOPTS"
+GCC_BUILD testgcc1 ""
+GCC_BUILD testgcc2 "$CMAKEOPTS"
+GCC_BUILD testgcc3 "$UUCCMAKEOPTS"
+GCC_BUILD testgcc4glib "$GLIBOPTS"
 if (test "`uname -s`" = "Linux")
 then
     echo "Temporarily disable cross-compile tests"
-#  GCC_BUILD test1cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake"
-#  GCC_BUILD test2cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake $CMAKEOPTS"
+#  GCC_BUILD testgcc1cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake"
+#  GCC_BUILD testgcc2cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake $CMAKEOPTS"
 fi
-GCC_BUILD test1builtin "-DUSE_BUILTIN_TZDATA=True"
-GCC_BUILD test2builtin "$TZCMAKEOPTS"
+GCC_BUILD testgcc1builtin "-DUSE_BUILTIN_TZDATA=True"
+GCC_BUILD testgcc2builtin "$TZCMAKEOPTS"
 
 #Clang based build tests
-CLANG_BUILD test1 ""
-CLANG_BUILD test2 "$CMAKEOPTS"
-CLANG_BUILD test3 "$UUCCMAKEOPTS"
-CLANG_BUILD test4 "$GLIBOPTS"
+CLANG_BUILD testclang1 ""
+CLANG_BUILD testclang2 "$CMAKEOPTS"
+CLANG_BUILD testclang3 "$UUCCMAKEOPTS"
+#broken with clang7 on Fedora29 CLANG_BUILD testclang4glib "$GLIBOPTS"
 if (test "`uname -s`" = "Linux")
 then
     echo "Temporarily disable cross-compile tests"
-#  CLANG_BUILD test1cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake"
-#  CLANG_BUILD test2cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake $CMAKEOPTS"
+#  CLANG_BUILD testclang1cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake"
+#  CLANG_BUILD testclang2cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake $CMAKEOPTS"
 fi
 
 #Address sanitizer
