@@ -2,18 +2,18 @@
  FILE: icalcomponent.c
  CREATOR: eric 28 April 1999
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
+ (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at http://www.mozilla.org/MPL/
+    the License at https://www.mozilla.org/MPL/
 ======================================================================*/
 
 #ifdef HAVE_CONFIG_H
@@ -30,6 +30,7 @@
 
 #include <assert.h>
 #include <stdlib.h>
+#include <limits.h>
 
 struct icalcomponent_impl
 {
@@ -2650,66 +2651,75 @@ void icalcomponent_normalize(icalcomponent *comp)
     pvl_list sorted_props = pvl_newlist();
     pvl_list sorted_comps = pvl_newlist();
     icalproperty *prop;
-    icalcomponent *mycomp;
+    icalcomponent *sub;
 
+    /* Normalize properties into sorted list */
     while ((prop = pvl_pop(comp->properties)) != 0) {
-        int nparams = icalproperty_count_parameters(prop);
-
-        /* Skip unparameterized properties having default values */
-        switch (icalproperty_isa(prop)) {
-        case ICAL_CALSCALE_PROPERTY:
-            if ((nparams == 0) &&
-                (strcmp("GREGORIAN", icalproperty_get_calscale(prop)) == 0)) {
-                continue;
-            }
-            break;
-
-        case ICAL_CLASS_PROPERTY:
-            if ((nparams == 0) &&
-                (icalproperty_get_class(prop) == ICAL_CLASS_PUBLIC)) {
-                continue;
-            }
-            break;
-
-        case ICAL_PRIORITY_PROPERTY:
-            if ((nparams == 0) && (icalproperty_get_priority(prop) == 0)) {
-                continue;
-            }
-            break;
-
-        case ICAL_TRANSP_PROPERTY:
-            if ((nparams == 0) &&
-                (icalproperty_get_transp(prop) == ICAL_TRANSP_OPAQUE)) {
-                continue;
-            }
-            break;
-
-        case ICAL_REPEAT_PROPERTY:
-            if ((nparams == 0) && (icalproperty_get_repeat(prop) == 0)) {
-                continue;
-            }
-            break;
-
-        case ICAL_SEQUENCE_PROPERTY:
-            if ((nparams == 0) && (icalproperty_get_sequence(prop) == 0)) {
-                continue;
-            }
-            break;
-
-        default:
-            break;
-        }
+        int nparams, remove = 0;
 
         icalproperty_normalize(prop);
-        pvl_insert_ordered(sorted_props, prop_compare, prop);
+
+        nparams = icalproperty_count_parameters(prop);
+
+        /* Remove unparameterized properties having default values */
+        if (nparams == 0) {
+            switch (icalproperty_isa(prop)) {
+            case ICAL_CALSCALE_PROPERTY:
+                if (strcmp("GREGORIAN", icalproperty_get_calscale(prop)) == 0) {
+                    remove = 1;
+                }
+                break;
+
+            case ICAL_CLASS_PROPERTY:
+                if (icalproperty_get_class(prop) == ICAL_CLASS_PUBLIC) {
+                    remove = 1;
+                }
+                break;
+
+            case ICAL_PRIORITY_PROPERTY:
+                if (icalproperty_get_priority(prop) == 0) {
+                    remove = 1;
+                }
+                break;
+
+            case ICAL_TRANSP_PROPERTY:
+                if (icalproperty_get_transp(prop) == ICAL_TRANSP_OPAQUE) {
+                    remove = 1;
+                }
+                break;
+
+            case ICAL_REPEAT_PROPERTY:
+                if (icalproperty_get_repeat(prop) == 0) {
+                    remove = 1;
+                }
+                break;
+
+            case ICAL_SEQUENCE_PROPERTY:
+                if (icalproperty_get_sequence(prop) == 0) {
+                    remove = 1;
+                }
+                break;
+
+            default:
+                break;
+            }
+        }
+
+        if (remove) {
+            icalproperty_set_parent(prop, 0); // MUST NOT have a parent to free
+            icalproperty_free(prop);
+        } else {
+            pvl_insert_ordered(sorted_props, prop_compare, prop);
+        }
     }
 
     pvl_free(comp->properties);
     comp->properties = sorted_props;
 
-    while ((mycomp = pvl_pop(comp->components)) != 0) {
-        icalcomponent_normalize(mycomp);
-        pvl_insert_ordered(sorted_comps, comp_compare, mycomp);
+    /* Normalize sub-components into sorted list */
+    while ((sub = pvl_pop(comp->components)) != 0) {
+        icalcomponent_normalize(sub);
+        pvl_insert_ordered(sorted_comps, comp_compare, sub);
     }
 
     pvl_free(comp->components);
