@@ -2,19 +2,18 @@
  FILE: icalproperty.c
  CREATOR: eric 28 April 1999
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
-     http://www.softwarestudio.org
+ (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at http://www.mozilla.org/MPL/
+    the License at https://www.mozilla.org/MPL/
 
   The original code is icalproperty.c
 ======================================================================*/
@@ -238,7 +237,7 @@ static char *get_next_line_start(char *line_start, size_t chars_left)
     }
     /* Now try to split on a UTF-8 boundary defined as a 7-bit
        value or as a byte with the two high-most bits set:
-       11xxxxxx.  See http://czyborra.com/utf/ */
+       11xxxxxx.  See https://czyborra.com/utf/ */
 
     pos = line_start + MAX_LINE_LEN - 1;
     while (pos > line_start) {
@@ -966,15 +965,18 @@ void icalproperty_normalize(icalproperty *prop)
     pvl_list sorted_params = pvl_newlist();
     icalparameter *param;
 
+    /* Normalize parameters into sorted list */
     while ((param = pvl_pop(prop->parameters)) != 0) {
-        /* Skip parameters having default values */
+        int remove = 0;
+
+        /* Remove parameters having default values */
         switch (icalparameter_isa(param)) {
         case ICAL_VALUE_PARAMETER:
             /* Skip VALUE parameters for default property value types */
             switch (prop_kind) {
             case ICAL_ATTACH_PROPERTY:
                 if (icalparameter_get_value(param) == ICAL_VALUE_URI) {
-                    continue;
+                    remove = 1;
                 }
                 break;
 
@@ -985,13 +987,13 @@ void icalproperty_normalize(icalproperty *prop)
             case ICAL_RDATE_PROPERTY:
             case ICAL_RECURRENCEID_PROPERTY:
                 if (icalparameter_get_value(param) == ICAL_VALUE_DATETIME) {
-                    continue;
+                    remove = 1;
                 }
                 break;
 
             case ICAL_DURATION_PROPERTY:
                 if (icalparameter_get_value(param) == ICAL_VALUE_DURATION) {
-                    continue;
+                    remove = 1;
                 }
                 break;
 
@@ -1002,55 +1004,55 @@ void icalproperty_normalize(icalproperty *prop)
 
         case ICAL_CUTYPE_PARAMETER:
             if (icalparameter_get_cutype(param) == ICAL_CUTYPE_INDIVIDUAL) {
-                continue;
+                remove = 1;
             }
             break;
 
         case ICAL_ENCODING_PARAMETER:
             if (icalparameter_get_encoding(param) == ICAL_ENCODING_8BIT) {
-                continue;
+                remove = 1;
             }
             break;
 
         case ICAL_FBTYPE_PARAMETER:
             if (icalparameter_get_fbtype(param) == ICAL_FBTYPE_BUSY) {
-                continue;
+                remove = 1;
             }
             break;
 
         case ICAL_PARTSTAT_PARAMETER:
             if (icalparameter_get_partstat(param) == ICAL_PARTSTAT_NEEDSACTION) {
-                continue;
+                remove = 1;
             }
             break;
 
         case ICAL_RELATED_PARAMETER:
             if (icalparameter_get_related(param) == ICAL_RELATED_START) {
-                continue;
+                remove = 1;
             }
             break;
 
         case ICAL_RELTYPE_PARAMETER:
             if (icalparameter_get_reltype(param) == ICAL_RELTYPE_PARENT) {
-                continue;
+                remove = 1;
             }
             break;
 
         case ICAL_ROLE_PARAMETER:
             if (icalparameter_get_role(param) == ICAL_ROLE_REQPARTICIPANT) {
-                continue;
+                remove = 1;
             }
             break;
 
         case ICAL_RSVP_PARAMETER:
             if (icalparameter_get_rsvp(param) == ICAL_RSVP_FALSE) {
-                continue;
+                remove = 1;
             }
             break;
 
         case ICAL_SCHEDULEAGENT_PARAMETER:
             if (icalparameter_get_scheduleagent(param) == ICAL_SCHEDULEAGENT_SERVER) {
-                continue;
+                remove = 1;
             }
             break;
 
@@ -1058,7 +1060,12 @@ void icalproperty_normalize(icalproperty *prop)
             break;
         }
 
-        pvl_insert_ordered(sorted_params, param_compare, param);
+        if (remove) {
+            icalparameter_set_parent(param, 0); // MUST NOT have a parent to free
+            icalparameter_free(param);
+        } else {
+            pvl_insert_ordered(sorted_params, param_compare, param);
+        }
     }
 
     pvl_free(prop->parameters);
