@@ -9,12 +9,12 @@
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at http://www.mozilla.org/MPL/
+    the License at https://www.mozilla.org/MPL/
  */
 
 #include "icalproperty_cxx.h"
@@ -26,15 +26,14 @@ ICalProperty::ICalProperty() : imp(icalproperty_new(ICAL_ANY_PROPERTY))
 {
 }
 
-ICalProperty::ICalProperty(const ICalProperty &v) throw(icalerrorenum)
-    : imp(icalproperty_new_clone(v.imp))
+ICalProperty::ICalProperty(const ICalProperty &v) : imp(icalproperty_new_clone(v.imp))
 {
     if (imp == NULL) {
         throw icalerrno;
     }
 }
 
-ICalProperty &ICalProperty::operator=(const ICalProperty &v) throw(icalerrorenum)
+ICalProperty &ICalProperty::operator=(const ICalProperty &v)
 {
     if (this == &v) {
         return *this;
@@ -67,7 +66,7 @@ ICalProperty::ICalProperty(icalproperty *v) : imp(v)
 {
 }
 
-ICalProperty::ICalProperty(std::string str)
+ICalProperty::ICalProperty(std::string str) //NOLINT TODO:V3.1:pass const ref
     : imp(icalproperty_new_from_string(str.c_str()))
 {
 }
