@@ -2,19 +2,18 @@
  FILE: icalrecur.c
  CREATOR: eric 16 May 2000
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
-     http://www.softwarestudio.org
+ (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at http://www.mozilla.org/MPL/
+    the License at https://www.mozilla.org/MPL/
 ========================================================================*/
 
 /**
@@ -609,11 +608,21 @@ struct icalrecurrencetype icalrecurrencetype_from_string(const char *str)
             }
         } else if (strcasecmp(name, "COUNT") == 0) {
             parser.rt.count = atoi(value);
-            /* don't allow count to be less than 1 */
-            if (parser.rt.count < 1) r = -1;
+            if (parser.rt.count < 1) {
+                /* don't allow count to be less than 1 */
+                r = -1;
+            } else if (!icaltime_is_null_time(parser.rt.until)) {
+                /* don't allow both count and until */
+                r = -1;
+            }
         } else if (strcasecmp(name, "UNTIL") == 0) {
             parser.rt.until = icaltime_from_string(value);
-            if (icaltime_is_null_time(parser.rt.until)) r = -1;
+            if (icaltime_is_null_time(parser.rt.until)) {
+                r = -1;
+            } else if (parser.rt.count > 0) {
+               /* don't allow both count and until */
+               r = -1;
+            }
         } else if (strcasecmp(name, "INTERVAL") == 0) {
             parser.rt.interval = (short)atoi(value);
             /* don't allow an interval to be less than 1
@@ -720,7 +729,7 @@ char *icalrecurrencetype_as_string_r(struct icalrecurrencetype *recur)
     char temp[20];
     int i, j;
 
-    if (recur->freq == ICAL_NO_RECURRENCE) {
+    if (recur == 0 || recur->freq == ICAL_NO_RECURRENCE) {
         return 0;
     }
 
@@ -750,7 +759,7 @@ char *icalrecurrencetype_as_string_r(struct icalrecurrencetype *recur)
         icalmemory_append_string(&str, &str_p, &buf_sz, temp);
     }
 
-    if (recur->count != 0) {
+    else if (recur->count != 0) {
         snprintf(temp, sizeof(temp), "%d", recur->count);
         icalmemory_append_string(&str, &str_p, &buf_sz, ";COUNT=");
         icalmemory_append_string(&str, &str_p, &buf_sz, temp);
@@ -1605,7 +1614,7 @@ static int get_day_of_week(icalrecur_iterator *impl)
 }
 
 /* Calculate ISO weeks per year
-   http://en.wikipedia.org/wiki/ISO_week_date#Weeks_per_year */
+   https://en.wikipedia.org/wiki/ISO_week_date#Weeks_per_year */
 static int weeks_in_year(int year)
 {
     /* Long years occur when year starts on Thu or leap year starts on Wed */
@@ -1616,7 +1625,7 @@ static int weeks_in_year(int year)
 }
 
 /* Calculate ISO week number
-   http://en.wikipedia.org/wiki/ISO_week_date#Calculation */
+   https://en.wikipedia.org/wiki/ISO_week_date#Calculation */
 static int get_week_number(icalrecur_iterator *impl, struct icaltimetype tt)
 {
     int dow, week;
@@ -2949,6 +2958,11 @@ static int __iterator_set_start(icalrecur_iterator *impl, icaltimetype start)
         } else {
             adjust_to_byday(impl);
 
+            /* If start == DTSTART, adjust rstart */
+            if (icaltime_compare(start, impl->dtstart) == 0) {
+                impl->rstart = occurrence_as_icaltime(impl, 0);
+            }
+
             /* Get (adjusted) start date as RSCALE date */
             start = occurrence_as_icaltime(impl, 0);
 
