@@ -8,12 +8,12 @@
  * it under the terms of either:
  *
  *   The LGPL as published by the Free Software Foundation, version
- *   2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+ *   2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
  *
  * Or:
  *
  *   The Mozilla Public License Version 2.0. You may obtain a copy of
- *   the License at http://www.mozilla.org/MPL/
+ *   the License at https://www.mozilla.org/MPL/
  */
 //krazy:excludeall=cpp
 
@@ -26,6 +26,7 @@
 #include "icaltimezone.h"
 
 #include <stdlib.h>
+#include <limits.h>
 
 #if defined(sun) && defined(__SVR4)
 #include <sys/types.h>
@@ -309,17 +310,21 @@ icalcomponent *icaltzutil_fetch_timezone(const char *location)
     num_isstd = (size_t)decode(type_cnts.ttisstdcnt);
     num_types = (size_t)decode(type_cnts.typecnt);
 
-    transitions = calloc(num_trans, sizeof(time_t));
-    if (transitions == NULL) {
-        icalerror_set_errno(ICAL_NEWFAILED_ERROR);
+    if (num_trans > 0) {
+        transitions = calloc(num_trans, sizeof(time_t));
+        if (transitions == NULL) {
+            icalerror_set_errno(ICAL_NEWFAILED_ERROR);
+            goto error;
+        }
+        r_trans = calloc(num_trans, 4);
+        if (r_trans == NULL) {
+            icalerror_set_errno(ICAL_NEWFAILED_ERROR);
+            goto error;
+        }
+    } else {
+        icalerror_set_errno(ICAL_FILE_ERROR);
         goto error;
     }
-    r_trans = calloc(num_trans, 4);
-    if (r_trans == NULL) {
-        icalerror_set_errno(ICAL_NEWFAILED_ERROR);
-        goto error;
-    }
-
     EFREAD(r_trans, 4, num_trans, f);
     temp = r_trans;
     if (num_trans) {
