@@ -2,19 +2,18 @@
  FILE: icalgauge.c
  CREATOR: eric 23 December 1999
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
-     http://www.softwarestudio.org
+ (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at http://www.mozilla.org/MPL/
+    the License at https://www.mozilla.org/MPL/
 
  The Original Code is eric. The Initial Developer of the Original
  Code is Eric Busboom
@@ -67,7 +66,11 @@ icalgauge *icalgauge_new_from_sql(const char *sql, int expand)
 
 int icalgauge_get_expand(icalgauge *gauge)
 {
-    return (gauge->expand);
+    icalerror_check_arg_rz((gauge != 0), "gauge");
+    if (gauge != 0) {
+        return gauge->expand;
+    }
+    return -1;
 }
 
 void icalgauge_free(icalgauge *gauge)
