@@ -3,30 +3,30 @@
 # FILE: Component.py
 # CREATOR: eric
 #
-# (C) COPYRIGHT 2001, Eric Busboom <eric@softwarestudio.org>
+# (C) COPYRIGHT 2001, Eric Busboom <eric@civicknowledge.com>
 # (C) COPYRIGHT 2001, Patrick Lewis <plewis@inetarena.com>
 #
 # This library is free software; you can redistribute it and/or modify
 # it under the terms of either:
 #
 #   The LGPL as published by the Free Software Foundation, version
-#   2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.txt
+#   2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.txt
 #
 # Or:
 #
 #   The Mozilla Public License Version 2.0. You may obtain a copy of
-#   the License at http://www.mozilla.org/MPL/
+#   the License at https://www.mozilla.org/MPL/
 
 # This library is free software; you can redistribute it and/or modify
 # it under the terms of either:
 #
 #   The LGPL as published by the Free Software Foundation, version
-#   2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+#   2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 #
 # Or:
 #
 #   The Mozilla Public License Version 2.0. You may obtain a copy of
-#   the License at http://www.mozilla.org/MPL/
+#   the License at https://www.mozilla.org/MPL/
 #======================================================================
 
 from LibicalWrap import *
@@ -59,7 +59,6 @@ class Component(object):
 
     def __init__(self,ref=None,kind=None):
 
-        self._ref = None
         if ref != None:
             self._ref = ref
         elif kind != None:
@@ -71,7 +70,7 @@ class Component(object):
             icalcomponent_add_component(self._ref,inner);
 
         else:
-            raise "Could not construct component of with an unspecified kind"
+            raise "Could not construct component with an unspecified kind"
 
         self.cached_props = SwigRefHash()
         self.cached_comps = SwigRefHash()
@@ -126,10 +125,7 @@ class Component(object):
 
        if p !=WrapperNULL:
            self._prop_from_ref(p)
-           prop =  self.cached_props[p]
-           return prop
-       else :
-           return None
+           return self.cached_props[p]
 
     def properties(self,type='ANY'):
         """
@@ -202,10 +198,8 @@ class Component(object):
 
         inner = icalcomponent_get_inner(self._ref)
 
-        if inner == WrapperNULL and inner != None:
-            return None
-
-        return NewComponent(inner)
+        if inner != WrapperNULL or inner is None:
+            return NewComponent(inner)
 
     def add_component(self, comp):
         "Adds a child component."
@@ -615,7 +609,7 @@ class GenericComponent(Component):
         Examples:
         # Set using string[s]
         categories(('APPOINTMENT', 'EDUCATION'))
-        # Returns a list of Category properites
+        # Returns a list of Category properties
         categories()
 
         When setting the attendees, any previous category Properties in the
@@ -793,7 +787,7 @@ class Todo(GenericComponent):
 
     def duration(self, value=None):
         if value != None:
-            due = self.properites('DUE')
+            due = self.properties('DUE')
             for d in due:
                 self.remove_property(d)  # Clear DUE properties
         return self._singular_property("DURATION", "DURATION", value, Duration)
