@@ -2,19 +2,18 @@
  FILE: icalrecur_test.c
  CREATOR: Ken Murchison 26 September 2014
 
- (C) COPYRIGHT 2000 Eric Busboom <eric@softwarestudio.org>
-     http://www.softwarestudio.org
+ (C) COPYRIGHT 2000 Eric Busboom <eric@civicknowledge.com>
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at http://www.mozilla.org/MPL/
+    the License at https://www.mozilla.org/MPL/
 ======================================================================*/
 
 /*
@@ -364,6 +363,12 @@ const struct recur rfc5545[] = {
      "FREQ=WEEKLY;UNTIL=20170127T000000Z;WKST=MO;BYDAY=SU,TU,TH;INTERVAL=2",
      "20161231T090000"},
 
+    /* Bi-weekly on Sunday, Tuesday, and Thursday until January 27, 2017,
+       starting second day of 2017 */
+    {"20161229T090000",
+     "FREQ=WEEKLY;UNTIL=20170127T000000Z;WKST=MO;BYDAY=SU,TU,TH;INTERVAL=2",
+     "20170102T090000"},
+
     /* Every 3rd day in January, starting on the 10th */
     {"20170101T090000",
      "FREQ=DAILY;UNTIL=20170131T140000Z;BYMONTH=1;INTERVAL=3",
@@ -380,6 +385,11 @@ const struct recur rfc5545[] = {
      "FREQ=MONTHLY;INTERVAL=13;BYMONTH=5;COUNT=3",
      NULL},
 
+    /* github issue376 */
+    {"20190101T100000",
+     "FREQ=WEEKLY;BYDAY=WE,FR;INTERVAL=2;COUNT=4",
+     NULL},
+
     {NULL, NULL, NULL}
 };
 
